@@ -1,13 +1,39 @@
 package HPUX::LVM;
 
-require Exporter;
-@ISA = qw(Exporter);
-
-@EXPORT = qw();            # symbols to export by default
-
-$VERSION = sprintf "%d.%03d", q$Revision: 0.01 $ =~ /(\d+)\.(\d+)/;
-
+use 5.006;
 use strict;
+#use warnings;
+
+require Exporter;
+use AutoLoader qw(AUTOLOAD);
+
+our @ISA = qw(Exporter);
+
+# Items to export into callers namespace by default. Note: do not export
+# names by default without a very good reason. Use EXPORT_OK instead.
+# Do not simply export all your public functions/methods/constants.
+
+# This allows declaration	use HPUX::LVM ':all';
+# If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
+# will save memory.
+our %EXPORT_TAGS = ( 'all' => [ qw(
+	
+) ] );
+
+our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
+
+our @EXPORT = qw(
+	
+);
+our $VERSION = '1.03';
+
+# Preloaded methods go here.
+
+# Autoload methods go after =cut, and are processed by the autosplit program.
+
+### Start
+
+
 use vars '$AUTOLOAD';
 use Carp ;
 use Storable;
@@ -496,6 +522,7 @@ print "Got all $lvdatacnt2 of 14 logical volume data for $lvname\n\n" if $debug;
 					 print "tempdataline2 is   : $tempdataline[2]\n" if $debug;
 					 print "tempdataline3 is   : $tempdataline[3]\n" if $debug;
 					#add it here directly!
+					$vg_info{$vgname}->{lvols}->{$lvname}->{Ordered_PV}->{$lvpvcnt}=$tempdataline[1];
 					$vg_info{$vgname}->{lvols}->{$lvname}->{PV_Data}->{$tempdataline[1]}->{le_on_pv}=$tempdataline[2];
 					$vg_info{$vgname}->{lvols}->{$lvname}->{PV_Data}->{$tempdataline[1]}->{pe_on_pv}=$tempdataline[3];
 #$logical_volume_hash_data{$vgname}{$lvname}{LVPVDATA}=$lvdataline[2];
@@ -696,12 +723,6 @@ sub AUTOLOAD {
 
 	      }
 
-
-
-
-
-
-
 sub traverse	{
         my $self = shift;
         my $debug=0;
@@ -1050,6 +1071,30 @@ sub get_vg_lvol_attr_lvdisplay	{
 	$lvol_attr = $self->{$vol_group}->{lvols}->{$logical_vol}->{lvdata}->{$attr};
 	return $lvol_attr;
 				}
+
+sub get_vg_lvol_stripeorder    {
+#return an array
+#pass vg,lvol,phyvol
+
+        my ($self, @subargs) = @_;
+
+        my %arglist      =      (
+                volume_group     => ""   ,
+                logical_vol      => ""   ,
+                @subargs,
+                                );
+        my $vol_group   = $arglist{volume_group};
+        my $logical_vol = $arglist{logical_vol};
+        my $debug =0;
+        my $debug2=0;
+        my $mainkey;
+        my @lvol_stripeorder;
+        foreach $mainkey ( sort keys %{ $self->{$vol_group}->{lvols}->{$logical_vol}->{'Ordered_PV'} } ) {
+                push @lvol_stripeorder, $self->{$vol_group}->{lvols}->{$logical_vol}->{'Ordered_PV'}->{ $mainkey };
+                                                                          }
+        return \@lvol_stripeorder;
+                                }
+
 sub get_vg_lvol_physicalvols	{
 #return an array
 #pass vg,lvol,phyvol
@@ -1099,9 +1144,10 @@ sub get_vg_lvol_physicalvol_attr{
 	return $lvol_physvol_attr;
 				}
 
-
+### End
 1;
 __END__
+# Below is stub documentation for your module. You better edit it!
 
 =head1 NAME
 
@@ -1357,7 +1403,7 @@ I beleive that you have to be root to run this.
 
 =head1 AUTHOR
 
-Christopher White <chrwhite@seanet.com>
+Christopher White, <chrwhite@seanet.com>
 
 Copyright (C) 2001 Christopher White.  All rights reserved.  this program is fre
 e software;  you can redistribute it and/or modify it under the same terms as pe
@@ -1368,3 +1414,5 @@ rl itself.
 L<vgdisplay>(1M)
 L<lvdisplay>(1M)
 L<pvdisplay>(1M)
+
+=cut
